Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client represents the Client constructor (i.e., `new kinesis.Client()`) and returns a new Kinesis client object.
func (*Client) PutRecords ¶
PutRecords writes multiple data records into a Kinesis data stream in a single call.
type ModuleInstance ¶
type ModuleInstance struct {
*Client
// contains filtered or unexported fields
}
ModuleInstance represents an instance of the JS module for every VU.
func (*ModuleInstance) Exports ¶
func (mi *ModuleInstance) Exports() modules.Exports
Exports implements the modules.Instance interface and returns the exports of the JS module.
func (*ModuleInstance) NewClient ¶
func (mi *ModuleInstance) NewClient(call goja.ConstructorCall) *goja.Object
NewClient is the JS constructor for the Kinesis client based on the AWS SDK implementation.
It resolves credentials using the SDK's default credential chain and allows the Kinesis endpoint URL to be redefined by passing it as the first argument to the constructor call.
type RootModule ¶
type RootModule struct{}
RootModule is the global module object type. It is instantiated once per test run and will be used to create `k6/x/kinesis` module instances for each VU.
func (*RootModule) NewModuleInstance ¶
func (*RootModule) NewModuleInstance(vu modules.VU) modules.Instance
NewModuleInstance implements the modules.Module interface to return a new instance for each VU.